/*
** Module   : ReplaceInterface.java
** Abstract : Define REPLACE methods available via a handle instance 
**            for the EDITOR/COMBO-BOX/SELECTION-LIST/RADIO-SET widgets
**
** Copyright (c) 2014-2015, Golden Code Development Corporation.
** ALL RIGHTS RESERVED. Use is subject to license terms.
**
**           Golden Code Development Corporation
**                      CONFIDENTIAL
**
** -#- -I- --Date-- ---------------------------------Description---------------------------------
** 001 IAS 20150604 Created initial version.
*/

package com.goldencode.p2j.ui;

import com.goldencode.p2j.util.*;

public interface ReplaceInterface
{
   
   /**
.    * REPLACE (old-string, new-string, flag ) method for EDITOR
    * 
    * @param    from
    *           The source text.
    * @param    to
    *           The replacement text.
    * @param    flag
    *          the search mode
    * @return   <code>true</code> if the operation was successful.
    */
   @LegacyMethod(name = "REPLACE")
   public logical replace(character from, character to, integer flag);

   /**
.    * REPLACE (old-string, new-string, flag ) method for EDITOR
    * 
    * @param    from
    *           The source text.
    * @param    to
    *           The replacement text.
    * @param    flag
    *          the search mode
    * @return   <code>true</code> if the operation was successful.
    */
   @LegacyMethod(name = "REPLACE")
   public logical replace(String from, character to, integer flag);

//   /**
//.    * REPLACE (old-string, new-string, flag ) method for EDITOR
//    * 
//    * @param    from
//    *           The source text.
//    * @param    to
//    *           The replacement text.
//    * @param    flag
//    *          the search mode
//    * @return   <code>true</code> if the operation was successful.
//    */
//   @LegacyMethod(name = "REPLACE")
//   public logical replace(character from, String to, integer flag);

   /**
.    * REPLACE (old-string, new-string, flag ) method for EDITOR
    * 
    * @param    from
    *           The source text.
    * @param    to
    *           The replacement text.
    * @param    flag
    *          the search mode
    * @return   <code>true</code> if the operation was successful.
    */
   @LegacyMethod(name = "REPLACE")
   public logical replace(character from, character to, int flag);

   /**
.    * REPLACE (old-string, new-string, flag ) method for EDITOR
    * 
    * @param    from
    *           The source text.
    * @param    to
    *           The replacement text.
    * @param    flag
    *          the search mode
    * @return   <code>true</code> if the operation was successful.
    */
   @LegacyMethod(name = "REPLACE")
   public logical replace(String from, character to, int flag);

   /**
.    * REPLACE (old-string, new-string, flag ) method for EDITOR
    * 
    * @param    from
    *           The source text.
    * @param    to
    *           The replacement text.
    * @param    flag
    *          the search mode
    * @return   <code>true</code> if the operation was successful.
    */
   @LegacyMethod(name = "REPLACE")
   public logical replace(character from, String to, int flag);


   /**
    * REPLACE (new-label, new-value, list-index) method for COMBO-BOX/SELECTION-LIST
    * REPLACE (old-string, new-string, flag ) method for EDITOR
    * 
    * @param arg0
    *          new item's label for COMBO-BOX/SELECTION-LIST,
    *          the source text for EDITOR
    * @param arg1         
    *          new item's value for COMBO-BOX/SELECTION-LIST,
    *          replacement test for editor
    * @param arg2
    *          index of the item to be replaced for COMBO-BOX/SELECTION-LIST,
    *          the search mode for EDITOR
    * @return   <code>true</code> if the operation was successful.
    */
   @LegacyMethod(name = "REPLACE")
   public logical replace(String arg0, String arg1, integer arg2);
   
   /**
    * REPLACE (new-label, new-value, list-index) method for COMBO-BOX/SELECTION-LIST
    * REPLACE (old-string, new-string, flag ) method for EDITOR
    * 
    * @param arg0
    *          new item's label for COMBO-BOX/SELECTION-LIST,
    *          the source text for EDITOR
    * @param arg1         
    *          new item's value for COMBO-BOX/SELECTION-LIST,
    *          replacement test for editor
    * @param arg2
    *          index of the item to be replaced for COMBO-BOX/SELECTION-LIST,
    *          the search mode for EDITOR
    * @return   <code>true</code> if the operation was successful.
    */
   @LegacyMethod(name = "REPLACE")
   public logical replace(String arg0, String arg1, int arg2);

   /**
    * REPLACE(REPLACE (new-item-list, list-item )) method
    * (for COMBO-BOX and SELECTION-LIST)
    * 
    * @param newItemList
    *          new item list
    * @param listItem
    *          old item's value
    * @return   <code>true</code> if the operation was successful.
    */
   @LegacyMethod(name = "REPLACE")
   public logical replace(character newItemList, character listItem);

   /**
    * REPLACE(REPLACE (new-item-list, list-item )) method
    * (for COMBO-BOX and SELECTION-LIST)
    * 
    * @param newItemList
    *          new item list
    * @param listItem
    *          old item's value
    * @return   <code>true</code> if the operation was successful.
    */
   @LegacyMethod(name = "REPLACE")
   public logical replace(character newItemList, String listItem);

   /**
    * REPLACE(REPLACE (new-item-list, list-item )) method
    * (for COMBO-BOX and SELECTION-LIST)
    * 
    * @param newItemList
    *          new item list
    * @param listItem
    *          old item's value
    * @return   <code>true</code> if the operation was successful.
    */
   @LegacyMethod(name = "REPLACE")
   public logical replace(String newItemList, character listItem);

   /**
    * REPLACE(REPLACE (new-item-list, list-item )) method
    * (for COMBO-BOX and SELECTION-LIST)
    * 
    * @param newItemList
    *          new item list
    * @param listItem
    *          old item's value
    * @return   <code>true</code> if the operation was successful.
    */
   @LegacyMethod(name = "REPLACE")
   public logical replace(String newItemList, String listItem);

   /**
    * REPLACE (new-item-list, list-index ) method
    * (for COMBO-BOX and SELECTION-LIST)
    * 
    * @param newItemList
    *          new item list
    * @param listIndex
    *          old item's index
    * @return   <code>true</code> if the operation was successful.
    */
   @LegacyMethod(name = "REPLACE")
   public logical replace(character newItemList, integer listIndex);

   /**
    * REPLACE (new-item-list, list-index ) method
    * (for COMBO-BOX and SELECTION-LIST)
    * 
    * @param newItemList
    *          new item list
    * @param listIndex
    *          old item's index
    * @return   <code>true</code> if the operation was successful.
    */
   @LegacyMethod(name = "REPLACE")
   public logical replace(character newItemList, int listIndex);

   /**
    * REPLACE (new-item-list, list-index ) method
    * (for COMBO-BOX and SELECTION-LIST)
    * 
    * @param newItemList
    *          new item list
    * @param listIndex
    *          old item's index
    * @return   <code>true</code> if the operation was successful.
    */
   @LegacyMethod(name = "REPLACE")
   public logical replace(String newItemList, integer listIndex);

   /**
    * REPLACE (new-item-list, list-index ) method
    * (for COMBO-BOX and SELECTION-LIST)
    * 
    * @param newItemList
    *          new item list
    * @param listIndex
    *          old item's index
    * @return   <code>true</code> if the operation was successful.
    */
   @LegacyMethod(name = "REPLACE")
   public logical replace(String newItemList, int listIndex);

   /**
    * REPLACE (new-label, new-value, list-item) method for COMBO-BOX/SELECTION-LIST,
    * REPLACE (new-label, new-value, old-label) method for RADIO-SET
    * 
    * @param newLabel
    *          new item's label
    * @param newValue         
    *          new item's value
    * @param oldItem
    *          oldItem (old-label for the READIO-SET, and list-item for the COMBO-BOX/SELECTION-LIST)
    * @return   <code>true</code> if the operation was successful.
    */
   @LegacyMethod(name = "REPLACE")
   public logical replace(character newLabel, BaseDataType  newValue, character oldItem);

   /**
    * REPLACE (new-label, new-value, list-item) method for COMBO-BOX/SELECTION-LIST,
    * REPLACE (new-label, new-value, old-label) method for RADIO-SET
    * 
    * @param newLabel
    *          new item's label
    * @param newValue         
    *          new item's value
    * @param oldItem
    *          oldItem (old-label for the READIO-SET, and list-item for the COMBO-BOX/SELECTION-LIST)
    * @return   <code>true</code> if the operation was successful.
    */
   @LegacyMethod(name = "REPLACE")
   public logical replace(String newLabel, BaseDataType  newValue, character oldItem);

   /**
    * REPLACE (new-label, new-value, list-item) method for COMBO-BOX/SELECTION-LIST,
    * REPLACE (new-label, new-value, old-label) method for RADIO-SET
    * 
    * @param newLabel
    *          new item's label
    * @param newValue         
    *          new item's value
    * @param oldItem
    *          oldItem (old-label for the READIO-SET, and list-item for the COMBO-BOX/SELECTION-LIST)
    * @return   <code>true</code> if the operation was successful.
    */
   @LegacyMethod(name = "REPLACE")
   public logical replace(character newLabel, String  newValue, character oldItem);

   /**
    * REPLACE (new-label, new-value, list-item) method for COMBO-BOX/SELECTION-LIST,
    * REPLACE (new-label, new-value, old-label) method for RADIO-SET
    * 
    * @param newLabel
    *          new item's label
    * @param newValue         
    *          new item's value
    * @param oldItem
    *          oldItem (old-label for the READIO-SET, and list-item for the COMBO-BOX/SELECTION-LIST)
    * @return   <code>true</code> if the operation was successful.
    */
   @LegacyMethod(name = "REPLACE")
   public logical replace(String newLabel, String  newValue, character oldItem);

   /**
    * REPLACE (new-label, new-value, list-item) method for COMBO-BOX/SELECTION-LIST,
    * REPLACE (new-label, new-value, old-label) method for RADIO-SET
    * 
    * @param newLabel
    *          new item's label
    * @param newValue         
    *          new item's value
    * @param oldItem
    *          oldItem (old-label for the READIO-SET, and list-item for the COMBO-BOX/SELECTION-LIST)
    * @return   <code>true</code> if the operation was successful.
    */
   @LegacyMethod(name = "REPLACE")
   public logical replace(character newLabel, BaseDataType  newValue, String oldItem);

   /**
    * REPLACE (new-label, new-value, list-item) method for COMBO-BOX/SELECTION-LIST,
    * REPLACE (new-label, new-value, old-label) method for RADIO-SET
    * 
    * @param newLabel
    *          new item's label
    * @param newValue         
    *          new item's value
    * @param oldItem
    *          oldItem (old-label for the READIO-SET, and list-item for the COMBO-BOX/SELECTION-LIST)
    * @return   <code>true</code> if the operation was successful.
    */
   @LegacyMethod(name = "REPLACE")
   public logical replace(String newLabel, BaseDataType  newValue, String oldItem);

   /**
    * REPLACE (new-label, new-value, list-item) method for COMBO-BOX/SELECTION-LIST,
    * REPLACE (new-label, new-value, old-label) method for RADIO-SET
    * 
    * @param newLabel
    *          new item's label
    * @param newValue         
    *          new item's value
    * @param oldItem
    *          oldItem (old-label for the READIO-SET, and list-item for the COMBO-BOX/SELECTION-LIST)
    * @return   <code>true</code> if the operation was successful.
    */
   @LegacyMethod(name = "REPLACE")
   public logical replace(character newLabel, String  newValue, String oldItem);

   /**
    * REPLACE (new-label, new-value, list-item) method for COMBO-BOX/SELECTION-LIST,
    * REPLACE (new-label, new-value, old-label) method for RADIO-SET
    * 
    * @param newLabel
    *          new item's label
    * @param newValue         
    *          new item's value
    * @param oldItem
    *          oldItem (old-label for the READIO-SET, and list-item for the COMBO-BOX/SELECTION-LIST)
    * @return   <code>true</code> if the operation was successful.
    */
   @LegacyMethod(name = "REPLACE")
   public logical replace(String newLabel, String  newValue, String oldItem);

   /**
    * REPLACE (new-label, new-value, list-index) method for COMBO-BOX/SELECTION-LIST
    * 
    * @param newLabel
    *          new item's label
    * @param newValue         
    *          new item's value
    * @param listIndex
    *          index of the item to be replaced
    * @return   <code>true</code> if the operation was successful.
    */
   @LegacyMethod(name = "REPLACE")
   public logical replace(character newLabel, BaseDataType  newValue, integer listIndex);

   /**
    * REPLACE (new-label, new-value, list-index) method for COMBO-BOX/SELECTION-LIST
    * 
    * @param newLabel
    *          new item's label
    * @param newValue         
    *          new item's value
    * @param listIndex
    *          index of the item to be replaced
    * @return   <code>true</code> if the operation was successful.
    */
   @LegacyMethod(name = "REPLACE")
   public logical replace(String newLabel, BaseDataType newValue, integer listIndex);

   /**
    * REPLACE (new-label, new-value, list-index) method for COMBO-BOX/SELECTION-LIST
    * REPLACE (old-string, new-string, flag ) method for EDITOR
    * 
    * @param arg0
    *          new item's label for COMBO-BOX/SELECTION-LIST,
    *          the source text for EDITOR
    * @param arg1         
    *          new item's value for COMBO-BOX/SELECTION-LIST,
    *          replacement test for editor
    * @param arg2
    *          index of the item to be replaced for COMBO-BOX/SELECTION-LIST,
    *          the search mode for EDITOR
    * @return   <code>true</code> if the operation was successful.
    */
   @LegacyMethod(name = "REPLACE")
   public logical replace(character arg0, String arg1, integer arg2);

   /**
    * REPLACE (new-label, new-value, list-index) method for COMBO-BOX/SELECTION-LIST
    * 
    * @param newLabel
    *          new item's label
    * @param newValue         
    *          new item's value
    * @param listIndex
    *          index of the item to be replaced
    * @return   <code>true</code> if the operation was successful.
    */
   @LegacyMethod(name = "REPLACE")
   public logical replace(character newLabel, BaseDataType newValue, int listIndex);

   /**
    * REPLACE (new-label, new-value, list-index) method for COMBO-BOX/SELECTION-LIST
    * 
    * @param newLabel
    *          new item's label
    * @param newValue         
    *          new item's value
    * @param listIndex
    *          index of the item to be replaced
    * @return   <code>true</code> if the operation was successful.
    */
   @LegacyMethod(name = "REPLACE")
   public logical replace(String newLabel, BaseDataType  newValue, int listIndex);
}
