/*
** Module   : SelectableText.java
** Abstract : Define SELECTION-TEXT and related methods/attributes available via a handle 
**            instance for the EDITOR/COMBO-BOX/FILL-IN widgets.
**
** Copyright (c) 2014-2015, Golden Code Development Corporation.
** ALL RIGHTS RESERVED. Use is subject to license terms.
**
**           Golden Code Development Corporation
**                      CONFIDENTIAL
**
** -#- -I- --Date-- ---------------------------------Description---------------------------------
** 001 IAS 20150604 Created initial version.
*/

package com.goldencode.p2j.ui;

import com.goldencode.p2j.util.*;

public interface SelectableText
{
   /**
    * Get SELECTION-TEXT attribute.
    *
    * @return  SELECTION-TEXT value   
    */
   @LegacyAttribute(name = "SELECTION-TEXT")
   public character getSelectionText();

   /**
    * Get SELECTION-END attribute.
    *
    * @return  SELECTION-END value   
    */
   @LegacyAttribute(name = "SELECTION-END")
   public integer getSelectionEnd();

   /**
    * Get SELECTION-START attribute.
    *
    * @return  SELECTION-START value   
    */
   @LegacyAttribute(name = "SELECTION-START")
   public integer getSelectionStart();

   /**
    * Selects text in a widget between start and end points.
    * 
    * @param    start
    *           Starting offset.
    * @param    end
    *           Ending offset.
    *
    * @return   <code>true</code> if the operation succeeded.
    */
   @LegacyMethod(name = "SET-SELECTION")
   public logical setSelection(int64 start, int64 end);
   
   /**
    * Selects text in a widget between start and end points.
    * 
    * @param    start
    *           Starting offset.
    * @param    end
    *           Ending offset.
    *
    * @return   <code>true</code> if the operation succeeded.
    */
   @LegacyMethod(name = "SET-SELECTION")
   public logical setSelection(int64 start, int end);
   
   /**
    * Selects text in a widget between start and end points.
    * 
    * @param    start
    *           Starting offset.
    * @param    end
    *           Ending offset.
    *
    * @return   <code>true</code> if the operation succeeded.
    */
   @LegacyMethod(name = "SET-SELECTION")
   public logical setSelection(int start, int64 end);
   
   /**
    * Selects text in a widget between start and end points.
    * 
    * @param    start
    *           Starting offset.
    * @param    end
    *           Ending offset.
    *
    * @return   <code>true</code> if the operation succeeded.
    */
   @LegacyMethod(name = "SET-SELECTION")
   public logical setSelection(int start, int end);
   
   /**
    * Checks is text selection is action.
    * 
    * @return  <code>true</code> if text selection is active.
    */
   @LegacyAttribute(name = "TEXT-SELECTED")
   public logical isTextSelected();

   /**
    * Clears text selection
    */
   @LegacyMethod(name = "CLEAR-SELECTION")
   public logical clearSelection();
}
